==> enterprisemodules-pg_config-0.4.2.tar.gz: enterprisemodules-pg_config-0.4.2/lib/puppet/provider/pg_exec/psql.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/postgres/access'
require 'easy_type/helpers'
require 'fileutils'

Puppet::Type.type(:pg_exec).provide(:psql) do
  include EasyType::Helpers
  include EasyType::Template
  include Puppet_X::EnterpriseModules::Postgres::Access

  mk_resource_methods

  def flush
    return if resource[:refreshonly].to_s == 'true'

    execute
  end

  def onlyif?
    return true if resource[:onlyif].nil?

    value = execute_query(resource[:onlyif])
    message = if value
                "#{resource.path}: onlyif query returned record. So statement is executed."
              else
                "#{resource.path}: onlyif query returned no records. So statement is not executed."
              end
    Puppet.debug message
    value
  end

  def unless?
    return false if resource[:unless].nil?

    value = execute_query(resource[:unless])
    message = if value
                "#{resource.path}: unless query returned records. So statement is not executed."
              else
                "#{resource.path}: unless query returned no records. So statement is executed."
              end
    Puppet.debug message
    !value
  end

  #
  # Determine based on the values of unless and onlyif, if we
  # need to execute the main statement.
  #
  def need_to_execute?
    @unless_value = unless? if @unless_value.nil?
    @onlyif_value = onlyif? if @onlyif_value.nil?
    if resource.onlyif_specified? && !resource.unless_specified?
      @onlyif_value
    elsif !resource.onlyif_specified? && resource.unless_specified?
      @unless_value
    elsif resource.onlyif_specified? && resource.unless_specified?
      (@unless_value || @onlyif_value)
    else
      true
    end
  end

  def execute_query(query)
    db = db_from_resource
    options = { :db => db }
    options[:username] = resource[:role] if resource[:role]
    options[:password] = resource[:password] if resource[:password]
    rows = sql query, options
    rows.any?
  end

  def execute
    cwd           = resource[:cwd]
    statement     = resource[:statement]
    db = db_from_resource
    options = { :db => db, :parse => false }
    options[:catch_errors] = resource.mark_as_error unless resource.mark_as_error.nil?
    options[:failonsqlfail] = resource.report_errors?
    options[:username] = resource.role unless resource.role.nil?
    options[:password] = resource.password unless resource.password.nil?

    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)

    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    output = sql statement, options
    Puppet.debug(output) if resource.logoutput.to_s == 'true'
  end
end

==> enterprisemodules-pg_config-0.7.0.tar.gz: enterprisemodules-pg_config-0.7.0/lib/puppet/provider/pg_exec/psql.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/postgres/access'
require 'easy_type/helpers'
require 'fileutils'

Puppet::Type.type(:pg_exec).provide(:psql) do
  include EasyType::Helpers
  include EasyType::Template
  include PuppetX::EnterpriseModules::Postgres::Access

  mk_resource_methods

  def flush
    return if resource[:refreshonly].to_s == 'true'

    execute
  end

  def onlyif?
    return true if resource[:onlyif].nil?

    value = execute_query(resource[:onlyif])
    message = if value
                "#{resource.path}: onlyif query returned record. So statement is executed."
              else
                "#{resource.path}: onlyif query returned no records. So statement is not executed."
              end
    Puppet.debug message
    value
  end

  def unless?
    return false if resource[:unless].nil?

    value = execute_query(resource[:unless])
    message = if value
                "#{resource.path}: unless query returned records. So statement is not executed."
              else
                "#{resource.path}: unless query returned no records. So statement is executed."
              end
    Puppet.debug message
    !value
  end

  #
  # Determine based on the values of unless and onlyif, if we
  # need to execute the main statement.
  #
  def need_to_execute?
    @unless_value = unless? if @unless_value.nil?
    @onlyif_value = onlyif? if @onlyif_value.nil?
    if resource.onlyif_specified? && !resource.unless_specified?
      @onlyif_value
    elsif !resource.onlyif_specified? && resource.unless_specified?
      @unless_value
    elsif resource.onlyif_specified? && resource.unless_specified?
      (@unless_value || @onlyif_value)
    else
      true
    end
  end

  def execute_query(query)
    db = db_from_resource
    options = { :db => db }
    options[:username] = resource[:role] if resource[:role]
    options[:password] = resource[:password] if resource[:password]
    rows = sql query, options
    rows.any?
  end

  def execute
    cwd           = resource[:cwd]
    statement     = resource[:statement]
    db = db_from_resource
    options = { :db => db, :parse => false }
    options[:catch_errors] = resource.mark_as_error unless resource.mark_as_error.nil?
    options[:failonsqlfail] = resource.report_errors?
    options[:username] = resource.role unless resource.role.nil?
    options[:password] = resource.password unless resource.password.nil?

    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)

    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    output = sql statement, options
    Puppet.debug(output) if resource.logoutput.to_s == 'true'
  end
end
